# -*- coding = utf-8 -*-
# @time: 2022/4/18 5:08 下午
# @Author: erazhan
# @File: conn_pg.py

# ----------------------------------------------------------------------------------------------------------------------
import pymysql
import psycopg2

class MysqlConnection(object):
    def __init__(self,
                 host,
                 port,
                 user,
                 passwd,
                 database,
                 charset = 'utf8'):

        self.host = host
        self.port = port
        self.user = user
        self.passwd = passwd
        self.database = database
        self.charset = charset

    def get_conn(self, conn_type="psycopg"):

        if conn_type == "psycopg":
            conn = psycopg2.connect(
                database=self.database,
                user=self.user,
                password=self.passwd,
                port=self.port,
                host=self.host
            )

        if conn_type == "pymysql":
            conn = pymysql.connect(
                host=self.host,
                port=self.port,
                user=self.user,
                passwd=self.passwd,
                db=self.database,
                charset=self.charset,
            )
        return conn

    def query(self, sql, conn_type='psycopg'):

        conn = self.get_conn(conn_type=conn_type)
        cur = conn.cursor()

        cur.execute(sql)
        ans = cur.fetchall()

        cur.close()
        conn.close()

        return ans

    def insert_data_many(self, sql, data, conn_type="pymysql"):

        conn = self.get_conn(conn_type=conn_type)
        cur = conn.cursor()
        cur.executemany(sql, data)
        conn.commit()
        cur.close()
        conn.close()

        return

    def truncate(self, table):

        sql = "truncate table %s" % table
        conn = self.get_conn()
        cur = conn.cursor()
        cur.execute(sql)
        conn.commit()
        cur.close()
        conn.close()

        return

    def create_table(self, create_sql):
        conn = self.get_conn()
        cur = conn.cursor()
        cur.execute(create_sql)
        conn.commit()
        cur.close()
        conn.close()

    def delete(self, delete_sql):

        conn = self.get_conn()
        cur = conn.cursor()
        cur.execute(delete_sql)
        conn.commit()
        cur.close()
        conn.close()


# -*- coding = utf-8 -*-
# @time: 2022/2/23 3:17 下午
# @Author: erazhan
# @File: sklearn_utils.py

# ----------------------------------------------------------------------------------------------------------------------

from sklearn.metrics import confusion_matrix
from sklearn.metrics import accuracy_score
from sklearn.metrics import precision_score
from sklearn.metrics import recall_score
from sklearn.metrics import roc_auc_score
from sklearn.metrics import roc_curve
from sklearn.metrics import f1_score
from sklearn.metrics import auc

# ----------------------------------------------------------------------------------------------------------------------

def show_ml_metric(test_labels, predict_labels, predict_prob):
    accuracy = accuracy_score(test_labels, predict_labels)
    precision = precision_score(test_labels, predict_labels)
    recall = recall_score(test_labels, predict_labels)
    f1_measure = f1_score(test_labels, predict_labels)
    confusionMatrix = confusion_matrix(test_labels, predict_labels)
    fpr, tpr, threshold = roc_curve(test_labels, predict_prob, pos_label=1)
    Auc = auc(fpr, tpr)
    print("------------------------- ")
    print("confusion matrix:")
    print("------------------------- ")
    print("| TP: %5d | FP: %5d |" % (confusionMatrix[1, 1], confusionMatrix[0, 1]))
    print("----------------------- ")
    print("| FN: %5d | TN: %5d |" % (confusionMatrix[1, 0], confusionMatrix[0, 0]))
    print(" ------------------------- ")
    print("Accuracy:       %.2f%%" % (accuracy * 100))
    print("Recall:         %.2f%%" % (recall * 100))
    print("Precision:      %.2f%%" % (precision * 100))
    print("F1-measure:     %.2f%%" % (f1_measure * 100))
    print("AUC:            %.2f%%" % (Auc * 100))
    print("------------------------- ")
    return (Auc)

if __name__ == "__main__":
    pass


# coding:utf-8
# -*- coding = utf-8 -*-
# @time: 2022/2/21 11:22 上午
# @Author: erazhan
# @File: logging_utils.py

# ----------------------------------------------------------------------------------------------------------------------
import os
import time
import logging

def create_log_file(project_name = "emr",log_dir = "./app_logs", version = "test"):

    cur_time = time.strftime("%Y%m%d_%H%M%S")
    # mode='a'是会接在后面写的，mode='w'会覆盖掉之前日志
    app_log_name = "app_%s_%s_%s.log"%(project_name,version,cur_time)
    log_file = os.path.join(log_dir, app_log_name)
    return log_file

class FileLogger(object):

    '''
    使用方法：
    from utils import FileLogger

    # 需要区分
    test_FH = FileLogger("./logs")
    test_FH.create_logger(name = 'test')
    test_FH.logger.info("test logging")

    test_FH.create_logger(name = "new test")
    test_FH.logger.info("new test logging")
    '''

    def __init__(self, log_dir = "./app_logs/", update_type = "day"):

        if not os.path.exists(log_dir):
            os.mkdir(log_dir)

        self.log_dir = log_dir
        self.fh = None
        self.logger = None
        self.update_flag = True
        self.update_type = update_type

        self.last_mday = time.localtime().tm_mday
        self.last_min = time.localtime().tm_min
        self.last_sec = time.localtime().tm_sec

    # 创建logger
    def create_logger(self, log_file, logger_name = "disease", update_type = "day",encoding='utf-8'):

        assert update_type == self.update_type, "update_type 不一致"
        TN = time.localtime()

        # 后续更新时间
        if update_type == "day":
            if TN.tm_mday != self.last_mday:
                self.update_flag = True
                self.last_mday = TN.tm_mday
        elif update_type == "min":
            if TN.tm_min != self.last_min:
               self.update_flag = True
               self.last_min = TN.tm_min
        elif update_type == "sec":
            if TN.tm_sec != self.last_sec:
                self.update_flag = True
                self.last_sec = TN.tm_sec
        else:
            raise ValueError("update_type %s error, require day or min or sec"%(update_type))

        if self.update_flag == False:
            return
        print("需要更新logger",log_file,self.update_flag,self.last_mday,TN.tm_mday,TN.tm_min,TN.tm_sec)
        # 没有
        self.update_flag = False
        if self.fh is not None:
            self.logger.removeHandler(self.fh)
            print("移除原来fh",log_file, self.update_flag, self.last_mday, TN.tm_mday,TN.tm_min,TN.tm_sec)

        self.logger = logging.getLogger(logger_name)
        self.logger.setLevel(logging.DEBUG)

        # 多种formatter形式
        self.formatter = []

        self.formatter.append(logging.Formatter("%(message)s"))
        self.formatter.append(logging.Formatter("[line:%(lineno)d] - %(levelname)s:\n %(message)s"))
        self.formatter.append(logging.Formatter("[line:%(lineno)d] %(asctime)s - %(levelname)s : %(message)s"))
        self.formatter.append(logging.Formatter("%(asctime)s - %(levelname)s : %(message)s"))
        self.formatter.append(logging.Formatter('%(asctime)s - %(filename)s[line:%(lineno)d] - %(levelname)s: %(message)s'))

        self.fh = self.update_handler(self.formatter[4],log_file = log_file,encoding=encoding)

    # 每天凌晨更新日志文件
    def update_handler(self, formatter, log_file, encoding='utf-8'):

        new_fh = logging.FileHandler(log_file, mode='a',encoding = encoding)
        new_fh.setLevel(logging.INFO)
        new_fh.setFormatter(formatter)
        self.logger.addHandler(new_fh)

        return new_fh

def write_logger(text, the_FH, info_type = "info"):

    if info_type == "info":
        the_FH.logger.info(text)
    elif info_type == "debug":
        the_FH.logger.debug(text)
    elif info_type == "error":
        the_FH.logger.error(text)
    else:
        pass

def update_logger(the_FH, project_name, app_log_dir, app_version_name, logger_name,update_type = 'day'):

    app_log_file = create_log_file(project_name, app_log_dir, version=app_version_name)
    the_FH.create_logger(app_log_file, logger_name = logger_name,update_type=update_type)

if __name__ == "__main__":

    app_log_dir = "./app_logs"
    project_name = "expert"
    logger_name = "inte_triage_expert_in" # 不重要
    update_type = "min"  # "day"
    app_version_name = "v1_offline"

    # emr_FH = FileLogger(log_dir = app_log_dir)
    # emr_FH.create_logger(log_file = app_log_file, logger_name = app_version_name) # 例如: logger_name = "v5_online"

    the_FH = FileLogger(log_dir=app_log_dir, update_type=update_type)
    app_log_file = create_log_file(project_name, app_log_dir, version=app_version_name)
    the_FH.create_logger(app_log_file, logger_name=logger_name, update_type=update_type)

    write_logger("创建初始日志,进程pid:%d" % os.getpid(), the_FH, info_type="info")

    for i in range(70):

        update_logger(the_FH, project_name, app_log_dir, app_version_name, logger_name, update_type=update_type)
        write_logger("count:%d" % (i + 1), the_FH, info_type='info')
        time.sleep(1)



# -*- coding = utf-8 -*-
# @time: 2022/2/21 10:52 上午
# @Author: erazhan
# @File: os_utils.py

# ----------------------------------------------------------------------------------------------------------------------

import os

def test_os__path__dirname():
    # 得到当前文件的绝对路径
    print(os.path.dirname(os.path.abspath(__file__)))


def test_os__listdir(dir_path):
    # 得到指定文件夹下所有的文件和文件夹
    for one in os.listdir(dir_path):
        print(dir_path + one)


def test_os__path__isfile_or_isdir(file_or_dir_path):
    # 判断路径是文件还是文件夹
    if os.path.isfile(file_or_dir_path):
        print(file_or_dir_path, "is a file:")
    if os.path.isdir(file_or_dir_path):
        print(file_or_dir_path, "is a dir")


def test_os__path__exist(file_or_dir_path="./ostools.py"):
    ans = os.path.exists(file_or_dir_path)
    print("file_or_dir_path", file_or_dir_path, "\nans:", ans)


def test_os__getcwd():
    # 获取当前路径
    ans = os.getcwd()
    print(ans)


if __name__ == "__main__":
    test_os__path__exist()
    pass


# coding:utf-8
# -*- coding:utf-8 -*-
# @time: 2023/9/21 13:21
# @Author: erazhan
# @File: math_utils.py

# ----------------------------------------------------------------------------------------------------------------------
import math

def radian2angle(theta_radian):
    return theta_radian * 180/math.pi

def angle2radian(theta_angle):
    return theta_angle * math.pi/180

if __name__ == "__main__":

    raw_radian = math.pi
    print(raw_radian)

    angle = radian2angle(raw_radian)
    print(angle)

    radian = angle2radian(angle)
    print(radian)
    pass



# coding:utf-8
# -*- coding:utf-8 -*-
# @time: 2023/8/30 17:54
# @Author: erazhan
# @File: judge_utils.py

# ----------------------------------------------------------------------------------------------------------------------
from .constants import SUFFIX_TYPE_DICT


def judge_not(entity, record):
    """保留原名称，兼容老版本"""
    return judge_negative_entity(entity, record)


def judge_negative_entity(entity, record):
    """判断entity和否定词的组合是否包含在原句子中，用于检查NER是否仅识别到不加否定前缀或后缀的entity。
    比如：entity='没有发烧'，NER如果仅识别到'发烧'，则可通过此函数粗略判断到识别内容不全，
    """
    neg_words = ["没有", "没", "无", "不", "不是"]
    re_neg_words = ["没有", "没", "无"]
    # 否定词在前
    flag = any(nw + entity in record for nw in neg_words)
    # 否定词在后
    re_flag = any(entity + rnw in record for rnw in re_neg_words)
    return flag or re_flag


def judge_suffix(text, suffix_list):
    """判断文本是否包含列表中的后缀，如果包含后缀返回纯的文件名和后缀名称"""
    return any(text.strip().endswith(suffix) for suffix in suffix_list)


def split_name_and_suffix(text, suffix_list):
    """将文本中的后缀名分离成名称+后缀，比如'123.jpg' -> '123'+'.jpg'"""
    text = text.strip()
    hit_name = None
    hit_suffix = None
    for suffix in suffix_list:
        if text.endswith(suffix):
            hit_name = text.split(suffix)[0]
            hit_suffix = suffix
            break
    return hit_name, hit_suffix


def judge_suffix_type(text, suffix_type_dict = SUFFIX_TYPE_DICT):
    """判断文本字符串的后缀类型，适用于多种后缀类型文件的判断，默认采用SUFFIX_TYPE_DICT"""
    text = text.strip()
    for suffix_type, suffix_list in suffix_type_dict.items():
        if judge_suffix(text,suffix_list):
            return suffix_type
    return "文字"


if __name__ == "__main__":

    text = "123.jpg"
    suffix_list = [".jpg",".png"]

    res = judge_suffix(text,suffix_list=suffix_list)
    print(res)

    hit_name, hit_suffix = split_name_and_suffix(text,suffix_list)
    print(hit_name)
    print(hit_suffix)

    text_type = judge_suffix_type(text)
    print(text_type)

    ent = "发烧"
    raw_text = "发烧的没有"
    a = judge_negative_entity(ent, raw_text)

    print(a)
    pass



# -*- coding = utf-8 -*-
# @time: 2022/2/23 5:42 下午
# @Author: erazhan
# @File: trie_tree.py

# ----------------------------------------------------------------------------------------------------------------------

class TrieTree(object):
    """
    Trie 树的基本方法，用途包括：
    - 前向最大匹配计算
    - 繁简体词汇转换的前向最大匹配计算
    """

    def __init__(self):
        self.dict_trie = dict()
        self.depth = 0

    def add_node(self, word, typing):
        """
        向 Trie 树添加节点
        :param word: 字典中的词汇
        :param typing: 词汇类型
        :return: None
        """
        word = word.strip()
        if word not in ['', '\t', ' ', '\r']:
            tree = self.dict_trie
            depth = len(word)
            word = word.lower()  # 将所有的字母全部转换成小写
            for char in word:
                if char in tree:
                    tree = tree[char]
                else:
                    tree[char] = dict()
                    tree = tree[char]
            if depth > self.depth:
                self.depth = depth
            tree['type'] = typing

    def build_trie_tree(self, dict_list, typing):
        """ 创建 trie 树 """
        for word in dict_list:
            self.add_node(word, typing)

    def search(self, word):
        tree = self.dict_trie
        res = None
        step = 0  # step 计数索引位置
        for char in word:
            if char in tree:
                tree = tree[char]
                step += 1
                if 'type' in tree:
                    res = (step, tree['type'])
            else:
                break
        if res:
            return res
        return 1, None


class TrieFind(object):

    def __init__(self, dict_list):
        self.trie_tree_obj = TrieTree()
        for typing, entity_list in dict_list.items():
            self.trie_tree_obj.build_trie_tree(entity_list, typing)

    def __call__(self, text):

        record_list = list()
        i = 0
        text_length = len(text)

        while i < text_length:
            pointer_orig = text[i: self.trie_tree_obj.depth + i]
            pointer = pointer_orig.lower()
            step, typing = self.trie_tree_obj.search(pointer)
            print("st", step, typing)
            if typing is not None:
                record = {
                    'type': typing,
                    'text': pointer_orig[0: step],
                    'offset': [i, step + i]}
                record_list.append(record)
            i += step

        return record_list

    def search(self, word):

        tree = self.trie_tree_obj.dict_trie
        step = 0
        word = word.lower()
        for char in word:
            # print("char,", step, char, len(word))
            if char in tree:
                step += 1
                tree = tree[char]
                if "type" in tree and step == len(word):
                    return True
            else:
                return False
        return False


if __name__ == '__main__':
    '''利用字典树判断实体是否在提供的字典中'''
    L = ["没得高血压", "没高血压", "没高血"]

    neg_tree = TrieFind({"否定词": L})

    for one_ent in L:
        a = neg_tree.search(one_ent)
        if a is False:
            print(one_ent)

    entity = "没高血压的"
    a = neg_tree.search(entity)
    print(a)


# -*- coding = utf-8 -*-
# @time: 2022/2/21 10:55 上午
# @Author: erazhan
# @File: json_utils.py

# ----------------------------------------------------------------------------------------------------------------------
import json

def save_txt_file(filename,entity_list):

    with open(filename,encoding='utf-8',mode ='w') as f:
        for one_entity in entity_list:
            f.write(one_entity + '\n')

def read_txt_file(txt_filename):

    '''
    :param txt_filename:必须是txt文件并且每一行是一个实体
    :return: 实体列表
    注意这里不去重
    '''

    entity_list = []
    with open(txt_filename,encoding = 'utf-8',mode = 'r') as f:
        for line in f.readlines():
            entity_list.append(line.strip())

    return entity_list

def save_json_file(filename,entities,mode = "indent"):

    # 需要将mode改成w才行
    # mode = 'w'正常，如果mode = 'a'那么用read_json_file读数据时会报错,因为此时写数据是接着之前的数据写，不会覆盖原有数据
    with open(filename,encoding='utf-8',mode = 'w') as f:

        if mode == "indent":
            f.write(json.dumps(entities,indent = 4,ensure_ascii=False, sort_keys = False, separators=(',', ':') ))
        else:
            f.write(json.dumps(entities, ensure_ascii=False))
        # f.write(json.dumps(entities,indent = 4,ensure_ascii=False, sort_keys = False, separators=(',',':') ))

def read_json_file(filename):

    with open(filename,'r',encoding = 'utf-8') as f:
        data = json.loads(f.read())

    return data

def trans2json(data):
    return json.dumps(data,indent = 4,ensure_ascii=False, sort_keys = False, separators=(',', ':'))

if __name__ == "__main__":
    pass


# -*- coding = utf-8 -*-
# @time: 2022/2/21 1:21 下午
# @Author: erazhan
# @File: test.py

# ----------------------------------------------------------------------------------------------------------------------

import os
import time
from logging_utils import create_log_file, FileLogger, update_logger, write_logger
from erazhan_utils import get_time

from time_utils import backto_Ntoday,trans_timestamp2str

def test_logging_utils():

    app_version = "v122"
    logger_name = "v122"
    app_log_dir = "./"
    project_name = "emr"
    app_log_file = create_log_file(project_name, app_log_dir, app_version)

    the_FH = FileLogger(app_log_dir)
    the_FH.create_logger(app_log_file, logger_name = logger_name) # logger_name = "v5_online"
    the_FH.logger.info("创建初始日志,进程pid:%d"%os.getpid())

    app_log_file = create_log_file(app_log_dir, app_version)
    the_FH.create_logger(app_log_file, logger_name = logger_name)
    text = "测试写入信息"
    write_logger(text,the_FH,info_type= 'info')
    for _ in range(61):
        print(_,get_time())
        time.sleep(1)
    update_logger(the_FH,project_name,app_log_dir,app_version,logger_name)
    text = "重新写入信息"
    write_logger(text, the_FH, info_type='info')

def test_time_utilst():

    int_time = int(time.time())
    str_time = trans_timestamp2str(int_time,data_format = "%Y:%m:%d %H:%M:%S")
    print("str_time:", str_time)

    Nday = backto_Ntoday(N=1,data_format="%Y%m%d")
    print("Nday:",Nday)

if __name__ == "__main__":
    # test_logging_utils()
    test_time_utilst()
    pass


# -*- coding = utf-8 -*-
# @time: 2022/2/23 3:01 下午
# @Author: erazhan
# @File: special_utils.py

# ----------------------------------------------------------------------------------------------------------------------
# 本文件设置一些其它的一些特殊通用

import time
from datetime import datetime
import re

def get_expire_date(N = 1, mode = "static", hour = 1):

    '''
    :param N: default = 1, N = 1, 接下去的第N天
    :param mode: defalut = "static": 固定在第N天的凌晨1点, "dynamic": 在当前时刻(精确到秒)后第N天的同一时刻
    :return:
    '''

    TN = time.localtime(time.time() + 86400 * N)

    # next_day
    year = TN.tm_year
    month = TN.tm_mon
    day = TN.tm_mday

    if mode == "static":
        # 设置为凌晨1点
        hour = hour
        minute = 0
        second = 0
    elif mode == "dynamic":
        # 第N天的同一时刻
        hour = TN.tm_hour
        minute = TN.tm_min
        second = TN.tm_sec
    else:
        raise ValueError("mode error: %s"%mode)

    dt = datetime(year, month, day, hour, minute, second)

    return dt

def remove_emoji(record):

    # content = "BGM好好听[失望][失望][失望][皱眉][皱眉]"

    # content = "chat:[破涕為笑]以前有过 chat:[微笑][握手] chat:[微笑][握手][握手] chat:[强]您的健康意识还是不错的"
    pattern = re.compile(r'\[.\]|\[..\]|\[...\]|\[....\]|\[.....\]|\[......\]')

    # emojis = pattern.findall(record) # 抽取表情包
    try:
        text = pattern.sub("", record) # 去除表情包
    except:
        text = record

    if len(text):
        return text
    else:
        return "空"

def remove_quote(record):

    record = "".join(record.strip().split())
    # quote = "- - - - - - - - - - - - - - -"
    quote = "---------------"
    if quote not in record:
        return record
    try:
        new_record = record.split(quote)[-1]
    except:
        new_record = record

    if len(new_record):
        return new_record
    else:
        return "空"

def trans_singleQM2doubleQM(text):
    '''将文本中的单引号转为双引号，便于后续使用json.loads
    QM: quotation marks
    '''
    try:
        text = re.sub('\'', '\"', text)
    except:
        pass

    return text

def sort_dict(raw_dict, sort_index = 1):

    new_dict = dict(sorted(list(raw_dict.items()),key = lambda x:x[sort_index],reverse= True))

    return new_dict

if __name__ == "__main__":

    pass


# -*- coding = utf-8 -*-
# @time: 2022/2/18 5:52 下午
# @Author: erazhan
# @File: setup.py

# ----------------------------------------------------------------------------------------------------------------------
from setuptools import setup, find_packages

setup(
    name = "erazhan_utils",
    version = "0.0.11",  # 暂时在__init__.py文件中自定义__version__

    keywords = ("erazhan_utils"),
    description = "some common tools in work",
    long_description = "some useful common tools",
    license = "MIT Licence",

    url = "https://github.com/erazhan/erazhan_utils",
    author = "erazhan",
    author_email = "erazhan@163.com",

    python_requires='>=3.6.1',  # 不需要太高的版本
    packages = find_packages(),
    include_package_data = True,
    platforms = "any",
    install_requires = []  # ["tensorflow==2.2.0","pandas"]#自行安装
)



# 版本更新需要保证代码兼容(原使用代码不出问题)
__version__ = "0.0.11"

from . import time_utils,json_utils,logging_utils
from . import os_utils,special_utils
# from . import sklearn_utils
from . import trie_tree

# 常用的一些函数，尽量保持不轻易变化
from .time_utils import get_time, get_today, backto_Ndays, backto_Ntoday
from .json_utils import read_json_file, save_json_file, read_txt_file, save_txt_file, trans2json
from .logging_utils import create_log_file, FileLogger, write_logger, update_logger
from .special_utils import remove_emoji,remove_quote,trans_singleQM2doubleQM,sort_dict
from .judge_utils import judge_not, judge_negative_entity, judge_suffix,split_name_and_suffix, judge_suffix_type
from .re_utils import clean_illegal_character
from .math_utils import radian2angle, angle2radian

from .constants import SUFFIX_TYPE_DICT, EN_PUNCTUATION,CN_PUNCTUATION,ALL_PUNCTUATION
#  from .conn_pg import MysqlConnection



# -*- coding = utf-8 -*-
# @time: 2022/2/18 5:49 下午
# @Author: erazhan
# @File: time_utils.py

# ----------------------------------------------------------------------------------------------------------------------
import time

def backto_Ndays(N, data_format = '%Y-%m-%d'):
    """计算前N天的0点时刻, N=1计算的是当天"""
    cutoff_time=time.strftime(data_format, time.localtime(time.time()-86400*(N-1)))+" 00:00:00"
    return cutoff_time

def backto_Ntoday(N, data_format = '%Y%m%d'):
    """计算前N天的日期名称, N=1计算的是当天"""
    cutoff_time=time.strftime(data_format, time.localtime(time.time()-86400*(N-1)))
    return cutoff_time

def get_time():
    return time.strftime("%Y-%m-%d %H:%M:%S")

def get_today():
    return time.strftime("%Y%m%d")

def is_leap_year(year):
    """
    判断是否为闰年:
    能被4整除且不能被100整除；能被400整除
    """
    if year % 400 == 0:
        return True
    if year % 4 == 0 and year % 100 != 0:
        return True
    return False

def get_month_day(year, month):
    """
    判断某年某月有几天
    """
    year = int(year)
    mon = int(month)
    assert mon >= 1 and mon <=12,"月份必须在1-12月"

    m_31 = [1,3,5,7,8,10,12]
    m_30 = [4,6,9,11]

    if mon == 2:
        if is_leap_year(year):
            return 29
        else:
            return 28
    if mon in m_30:
        return 30

    if mon in m_31:
        return 31

def trans_str2struct(str_time, date_format = "%Y-%m-%d %H:%M:%S"):
    """
    str转struct_time
    date_format = "%Y-%m-%d %H:%M:%S,%f
    struct_time中的tm_isdst表示是否为夏令时
    tm_isdst = -1表示不确定, = 0 代表不是, = 1代表是
    """
    return time.strptime(str_time, date_format)

def trans_struct2timestamp(struct_time):
    '''struct_time转timestamp'''
    return time.mktime(struct_time)

def trans_timestamp2struct(timestamp):
    '''timestamp转struct_time'''
    return time.localtime(timestamp)

def trans_struct2str(struct_time,data_format = "%Y-%m-%d %H:%M:%S"):
    """struct_time转str"""
    return time.strftime(data_format,struct_time)

def trans_timestamp2str(timestamp,data_format = "%Y-%m-%d %H:%M:%S"):
    """timestamp转str"""
    return trans_struct2str(trans_timestamp2struct(timestamp),data_format = data_format)

if __name__ == "__main__":
    pass


# coding:utf-8
# -*- coding:utf-8 -*-
# @time: 2023/9/21 11:07
# @Author: erazhan
# @File: re_utils.py

# ----------------------------------------------------------------------------------------------------------------------
import re

def clean_illegal_character(text, illegal_flag = 1):
    '''清洗文本中的非法字符，都是不常见的不可显示字符，例如退格，响铃等'''
    try:
        if illegal_flag == 1:
            ILLEGAL_CHARACTERS_RE = re.compile(r'[\000-\010]|[\013-\014]|[\016-\037]')
            text = ILLEGAL_CHARACTERS_RE.sub(r'', text)
        elif illegal_flag == 2:
            text = text.encode("utf-8").decode("utf-8-sig")
        else:
            text = text
    except:
        text = text
    return text




if __name__ == "__main__":

    text = "./ic15_data/recognition_train/﻿word_1.png"
    data = {"text":text}
    print(data)
    data["new_text"] = clean_illegal_character(text)
    print(data)

    nn_text = text.encode("utf-8").decode("utf-8-sig")
    print(nn_text)
